@@ -27,13 +27,11 @@
 #include "theme-util.h"
 #include "gtkrc-utils.h"
 #include "gedit-message-area.h"
-#include "wp-cellrenderer.h"
-#include "caption-cellrenderer.h"
 
 #include <glib/gi18n.h>
 #include <libwindow-settings/gnome-wm-manager.h>
 #include <string.h>
-#include <libgnomeui/gnome-thumbnail.h>
+#include <libgnomeui/gnome-desktop-thumbnail.h>
 
 #define CUSTOM_THEME_NAME "__custom__"
 
@@ -112,8 +110,8 @@ theme_thumbnail_update (GdkPixbuf *pixbuf,
       /* try to share thumbs with nautilus, use themes:/// */
       path = g_strconcat ("themes:///", theme_name, NULL);
 
-      gnome_thumbnail_factory_save_thumbnail (data->thumb_factory,
-					      pixbuf, path, mtime);
+      gnome_desktop_thumbnail_factory_save_thumbnail (data->thumb_factory,
+						      pixbuf, path, mtime);
 
       g_free (path);
     }
@@ -136,8 +134,8 @@ theme_get_thumbnail_from_cache (GnomeThemeMetaInfo *info, AppearanceData *data)
 
   /* try to share thumbs with nautilus, use themes:/// */
   path = g_strconcat ("themes:///", info->name, NULL);
-  thumb_filename = gnome_thumbnail_factory_lookup (data->thumb_factory,
-                                                   path, mtime);
+  thumb_filename = gnome_desktop_thumbnail_factory_lookup (data->thumb_factory,
+							   path, mtime);
   g_free (path);
 
   if (thumb_filename != NULL) {
@@ -172,6 +170,7 @@ theme_thumbnail_generate (GnomeThemeMetaInfo *info, AppearanceData *data)
 static void
 theme_changed_on_disk_cb (GnomeThemeCommonInfo *theme,
 			  GnomeThemeChangeType  change_type,
+                          GnomeThemeElement     element_type,
 			  AppearanceData       *data)
 {
   if (theme->type == GNOME_THEME_TYPE_METATHEME) {
@@ -360,7 +359,7 @@ static void
 theme_set_custom_from_theme (const GnomeThemeMetaInfo *info, AppearanceData *data)
 {
   GnomeThemeMetaInfo *custom = data->theme_custom;
-  GtkIconView *icon_view = GTK_ICON_VIEW (glade_xml_get_widget (data->xml, "theme_list"));
+  GtkIconView *icon_view = GTK_ICON_VIEW (appearance_capplet_get_widget (data, "theme_list"));
   GtkTreeModel *model;
   GtkTreeIter iter;
   GtkTreePath *path;
@@ -447,7 +446,7 @@ theme_message_area_response_cb (GtkWidget *w,
   gchar *tmpfont;
   gchar *engine_path;
 
-  theme = theme_get_selected (GTK_ICON_VIEW (glade_xml_get_widget (data->xml, "theme_list")), data);
+  theme = theme_get_selected (GTK_ICON_VIEW (appearance_capplet_get_widget (data, "theme_list")), data);
   if (!theme)
     return;
 
@@ -596,7 +595,7 @@ theme_message_area_update (AppearanceData *data)
   gchar *font;
   GError *error = NULL;
 
-  theme = theme_get_selected (GTK_ICON_VIEW (glade_xml_get_widget (data->xml, "theme_list")), data);
+  theme = theme_get_selected (GTK_ICON_VIEW (appearance_capplet_get_widget (data, "theme_list")), data);
 
   if (!theme) {
     if (data->theme_message_area != NULL)
@@ -702,7 +701,7 @@ theme_message_area_update (AppearanceData *data)
     gtk_box_pack_start (GTK_BOX (hbox), data->theme_message_label, TRUE, TRUE, 0);
     gedit_message_area_set_contents (GEDIT_MESSAGE_AREA (data->theme_message_area), hbox);
 
-    parent = glade_xml_get_widget (data->xml, "theme_list_vbox");
+    parent = appearance_capplet_get_widget (data, "theme_list_vbox");
     gtk_box_pack_start (GTK_BOX (parent), data->theme_message_area, FALSE, FALSE, 0);
   }
 
@@ -801,9 +800,9 @@ theme_selection_changed_cb (GtkWidget *icon_view, AppearanceData *data)
     g_list_free (selection);
   }
 
-  gtk_widget_set_sensitive (glade_xml_get_widget (data->xml, "theme_delete"),
+  gtk_widget_set_sensitive (appearance_capplet_get_widget (data, "theme_delete"),
 			    theme_is_writable (theme));
-  gtk_widget_set_sensitive (glade_xml_get_widget (data->xml, "theme_save"), is_custom);
+  gtk_widget_set_sensitive (appearance_capplet_get_widget (data, "theme_save"), is_custom);
 }
 
 static void
@@ -811,8 +810,8 @@ theme_custom_cb (GtkWidget *button, AppearanceData *data)
 {
   GtkWidget *w, *parent;
 
-  w = glade_xml_get_widget (data->xml, "theme_details");
-  parent = glade_xml_get_widget (data->xml, "appearance_window");
+  w = appearance_capplet_get_widget (data, "theme_details");
+  parent = appearance_capplet_get_widget (data, "appearance_window");
   gtk_window_set_transient_for (GTK_WINDOW (w), GTK_WINDOW (parent));
   gtk_widget_show_all (w);
 }
@@ -827,13 +826,13 @@ static void
 theme_install_cb (GtkWidget *button, AppearanceData *data)
 {
   gnome_theme_installer_run (
-      GTK_WINDOW (glade_xml_get_widget (data->xml, "appearance_window")), NULL);
+      GTK_WINDOW (appearance_capplet_get_widget (data, "appearance_window")), NULL);
 }
 
 static void
 theme_delete_cb (GtkWidget *button, AppearanceData *data)
 {
-  GtkIconView *icon_view = GTK_ICON_VIEW (glade_xml_get_widget (data->xml, "theme_list"));
+  GtkIconView *icon_view = GTK_ICON_VIEW (appearance_capplet_get_widget (data, "theme_list"));
   GList *selected = gtk_icon_view_get_selected_items (icon_view);
 
   if (selected) {
@@ -879,7 +878,7 @@ theme_details_changed_cb (AppearanceData *data)
   gconf_theme = theme_load_from_gconf (data->client);
 
   /* check if it's our currently selected theme */
-  icon_view = GTK_ICON_VIEW (glade_xml_get_widget (data->xml, "theme_list"));
+  icon_view = GTK_ICON_VIEW (appearance_capplet_get_widget (data, "theme_list"));
   selected = theme_get_selected (icon_view, data);
 
   if (!selected || !(done = theme_is_equal (selected, gconf_theme))) {
@@ -990,7 +989,7 @@ theme_drag_data_received_cb (GtkWidget *widget,
     GFile *f = g_file_new_for_uri (uris[0]);
 
     gnome_theme_install (f,
-        GTK_WINDOW (glade_xml_get_widget (data->xml, "appearance_window")));
+        GTK_WINDOW (appearance_capplet_get_widget (data, "appearance_window")));
     g_object_unref (f);
   }
 
@@ -1017,6 +1016,7 @@ themes_init (AppearanceData *data)
   GtkIconView *icon_view;
   GtkCellRenderer *renderer;
   GtkSettings *settings;
+  char *url;
 
   /* initialise some stuff */
   gnome_theme_init ();
@@ -1075,16 +1075,16 @@ themes_init (AppearanceData *data)
   g_list_foreach (theme_list, (GFunc) theme_thumbnail_generate, data);
   g_list_free (theme_list);
 
-  icon_view = GTK_ICON_VIEW (glade_xml_get_widget (data->xml, "theme_list"));
+  icon_view = GTK_ICON_VIEW (appearance_capplet_get_widget (data, "theme_list"));
 
-  renderer = cell_renderer_wallpaper_new ();
+  renderer = gtk_cell_renderer_pixbuf_new ();
   g_object_set (renderer, "xpad", 5, "ypad", 5,
                           "xalign", 0.5, "yalign", 1.0, NULL);
   gtk_cell_layout_pack_end (GTK_CELL_LAYOUT (icon_view), renderer, FALSE);
   gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (icon_view), renderer,
                                   "pixbuf", COL_THUMBNAIL, NULL);
 
-  renderer = cell_renderer_caption_new ();
+  renderer = gtk_cell_renderer_text_new ();
   g_object_set (renderer, "alignment", PANGO_ALIGN_CENTER,
 			  "wrap-mode", PANGO_WRAP_WORD_CHAR,
 			  "wrap-width", gtk_icon_view_get_item_width (icon_view),
@@ -1102,25 +1102,25 @@ themes_init (AppearanceData *data)
   g_signal_connect (icon_view, "selection-changed", (GCallback) theme_selection_changed_cb, data);
   g_signal_connect_after (icon_view, "realize", (GCallback) theme_select_name, meta_theme->name);
 
-  w = glade_xml_get_widget (data->xml, "theme_install");
+  w = appearance_capplet_get_widget (data, "theme_install");
   gtk_button_set_image (GTK_BUTTON (w),
                         gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_BUTTON));
   g_signal_connect (w, "clicked", (GCallback) theme_install_cb, data);
 
-  w = glade_xml_get_widget (data->xml, "theme_save");
+  w = appearance_capplet_get_widget (data, "theme_save");
   gtk_button_set_image (GTK_BUTTON (w),
                         gtk_image_new_from_stock (GTK_STOCK_SAVE_AS, GTK_ICON_SIZE_BUTTON));
   g_signal_connect (w, "clicked", (GCallback) theme_save_cb, data);
 
-  w = glade_xml_get_widget (data->xml, "theme_custom");
+  w = appearance_capplet_get_widget (data, "theme_custom");
   gtk_button_set_image (GTK_BUTTON (w),
                         gtk_image_new_from_stock (GTK_STOCK_EDIT, GTK_ICON_SIZE_BUTTON));
   g_signal_connect (w, "clicked", (GCallback) theme_custom_cb, data);
 
-  del_button = glade_xml_get_widget (data->xml, "theme_delete");
+  del_button = appearance_capplet_get_widget (data, "theme_delete");
   g_signal_connect (del_button, "clicked", (GCallback) theme_delete_cb, data);
 
-  w = glade_xml_get_widget (data->xml, "theme_vbox");
+  w = appearance_capplet_get_widget (data, "theme_vbox");
   gtk_drag_dest_set (w, GTK_DEST_DEFAULT_ALL,
 		     drop_types, G_N_ELEMENTS (drop_types),
 		     GDK_ACTION_COPY | GDK_ACTION_LINK | GDK_ACTION_MOVE);
@@ -1128,6 +1128,16 @@ themes_init (AppearanceData *data)
   if (is_locked_down (data->client))
     gtk_widget_set_sensitive (w, FALSE);
 
+  w = appearance_capplet_get_widget (data, "more_themes_linkbutton");
+  url = gconf_client_get_string (data->client, MORE_THEMES_URL_KEY, NULL);
+  if (url != NULL && url[0] != '\0') {
+    gtk_link_button_set_uri (GTK_LINK_BUTTON (w), url);
+    gtk_widget_show (w);
+  } else {
+    gtk_widget_hide (w);
+  }
+  g_free (url);
+
   /* listen to gconf changes, too */
   gconf_client_add_dir (data->client, "/apps/metacity/general", GCONF_CLIENT_PRELOAD_NONE, NULL);
   gconf_client_add_dir (data->client, "/desktop/gnome/interface", GCONF_CLIENT_PRELOAD_NONE, NULL);
@@ -1150,15 +1160,15 @@ themes_init (AppearanceData *data)
 
   /* monitor individual font choice buttons, so
      "revert font" option (if any) can be cleared */
-  w = glade_xml_get_widget (data->xml, "application_font");
+  w = appearance_capplet_get_widget (data, "application_font");
   g_signal_connect (w, "font_set", (GCallback) custom_font_cb, data);
-  w = glade_xml_get_widget (data->xml, "document_font");
+  w = appearance_capplet_get_widget (data, "document_font");
   g_signal_connect (w, "font_set", (GCallback) custom_font_cb, data);
-  w = glade_xml_get_widget (data->xml, "desktop_font");
+  w = appearance_capplet_get_widget (data, "desktop_font");
   g_signal_connect (w, "font_set", (GCallback) custom_font_cb, data);
-  w = glade_xml_get_widget (data->xml, "window_title_font");
+  w = appearance_capplet_get_widget (data, "window_title_font");
   g_signal_connect (w, "font_set", (GCallback) custom_font_cb, data);
-  w = glade_xml_get_widget (data->xml, "monospace_font");
+  w = appearance_capplet_get_widget (data, "monospace_font");
   g_signal_connect (w, "font_set", (GCallback) custom_font_cb, data);
 }
 
