@@ -21,9 +21,8 @@
 #include <glib.h>
 #include <gio/gio.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gtk/gtktreeview.h>
-#include <libgnomeui/gnome-thumbnail.h>
-#define GNOME_DESKTOP_USE_UNSTABLE_API
+#include <gtk/gtk.h>
+#include <libgnomeui/gnome-desktop-thumbnail.h>
 #include <libgnomeui/gnome-bg.h>
 
 #include "gnome-wp-info.h"
@@ -68,11 +67,14 @@ struct _GnomeWPItem {
 
 GnomeWPItem * gnome_wp_item_new (const gchar *filename,
 				 GHashTable *wallpapers,
-				 GnomeThumbnailFactory *thumbnails);
+				 GnomeDesktopThumbnailFactory *thumbnails);
 
 void gnome_wp_item_free (GnomeWPItem *item);
 GdkPixbuf * gnome_wp_item_get_thumbnail (GnomeWPItem *item,
-					 GnomeThumbnailFactory *thumbs);
+					 GnomeDesktopThumbnailFactory *thumbs);
+GdkPixbuf * gnome_wp_item_get_frame_thumbnail (GnomeWPItem *item,
+					 GnomeDesktopThumbnailFactory *thumbs,
+                                         gint frame);
 void gnome_wp_item_update (GnomeWPItem *item);
 void gnome_wp_item_update_description (GnomeWPItem *item);
 void gnome_wp_item_ensure_gnome_bg (GnomeWPItem *item);
