@@ -14,14 +14,11 @@
 #undef N_
 
 #include <glib.h>
-#include <libgnomeui/gnome-icon-theme.h>
 
 #include "theme-thumbnail.h"
 #include "gtkrc-utils.h"
 #include "capplet-util.h"
 
-static gint child_pid;
-
 typedef struct
 {
   gboolean set;
@@ -94,7 +91,6 @@ static int pipe_from_factory_fd[2];
 #define GTK_THUMBNAIL_SIZE         96
 #define METACITY_THUMBNAIL_WIDTH  120
 #define METACITY_THUMBNAIL_HEIGHT  60
-#define ICON_THUMBNAIL_SIZE        48
 
 
 static void
@@ -167,44 +163,35 @@ static GdkPixbuf *
 create_folder_icon (char *icon_theme_name)
 {
   GtkIconTheme *icon_theme;
-  GdkPixbuf *folder_icon = NULL, *retval;
+  GdkPixbuf *folder_icon = NULL;
   GtkIconInfo *folder_icon_info;
-  const gchar *filename;
   gchar *example_icon_name;
+  const gchar *icon_names[5];
+  gint i;
 
   icon_theme = gtk_icon_theme_new ();
   gtk_icon_theme_set_custom_theme (icon_theme, icon_theme_name);
 
-  folder_icon_info = NULL;
+  i = 0;
   /* Get the Example icon name in the theme if specified */
   example_icon_name = gtk_icon_theme_get_example_icon_name (icon_theme);
   if (example_icon_name != NULL)
-    folder_icon_info = gtk_icon_theme_lookup_icon (icon_theme, example_icon_name, 48, GTK_ICON_LOOKUP_FORCE_SVG);
-  g_free (example_icon_name);
-
-  /* If an Example is not specified, fall back to using the folder icons in
-     the order of Icon Nameing Spec, "gnome-fs-directory", and "folder" */
-  if (folder_icon_info == NULL)
-    folder_icon_info = gtk_icon_theme_lookup_icon (icon_theme, "x-directory-normal", 48, GTK_ICON_LOOKUP_FORCE_SVG);
-  if (folder_icon_info == NULL)
-    folder_icon_info = gtk_icon_theme_lookup_icon (icon_theme, "gnome-fs-directory", 48, GTK_ICON_LOOKUP_FORCE_SVG);
-  if (folder_icon_info == NULL)
-    folder_icon_info = gtk_icon_theme_lookup_icon (icon_theme, "folder", 48, GTK_ICON_LOOKUP_FORCE_SVG);
-
-  g_object_unref (icon_theme);
+    icon_names[i++] = example_icon_name;
+  icon_names[i++] = "x-directory-normal";
+  icon_names[i++] = "gnome-fs-directory";
+  icon_names[i++] = "folder";
+  icon_names[i++] = NULL;
 
+  folder_icon_info = gtk_icon_theme_choose_icon (icon_theme, icon_names, 48, GTK_ICON_LOOKUP_FORCE_SIZE);
   if (folder_icon_info != NULL)
   {
-    filename = gtk_icon_info_get_filename (folder_icon_info);
-
-    if (filename != NULL)
-    {
-      folder_icon = gdk_pixbuf_new_from_file (filename, NULL);
-    }
-
+    folder_icon = gtk_icon_info_load_icon (folder_icon_info, NULL);
     gtk_icon_info_free (folder_icon_info);
   }
 
+  g_object_unref (icon_theme);
+  g_free (example_icon_name);
+
   /* render the icon to the thumbnail */
   if (folder_icon == NULL)
   {
@@ -219,25 +206,7 @@ create_folder_icon (char *icon_theme_name)
     gtk_widget_destroy (dummy);
   }
 
-  /* Some icons don't come back at the requested dimensions, so we need to scale
-   * them. The width is usually the largest dimension for icons that come at
-   * irregular sizes, so use this to calculate the scale factor
-   */
-  if (gdk_pixbuf_get_width (folder_icon) != ICON_THUMBNAIL_SIZE) {
-    int width, height;
-    gdouble scale;
-
-    scale = ((double) ICON_THUMBNAIL_SIZE) / gdk_pixbuf_get_width (folder_icon);
-    width = ICON_THUMBNAIL_SIZE;
-    height = scale * gdk_pixbuf_get_height (folder_icon);
-
-    retval = gdk_pixbuf_scale_simple (folder_icon, width, height, GDK_INTERP_BILINEAR);
-    g_object_unref (folder_icon);
-  } else {
-    retval = folder_icon;
-  }
-
-  return retval;
+  return folder_icon;
 }
 
 static GdkPixbuf *
@@ -268,7 +237,10 @@ create_meta_theme_pixbuf (ThemeThumbnailData *theme_thumbnail_data)
     "gtk-icon-theme-name", (char *) theme_thumbnail_data->icon_theme_name->data,
     "gtk-color-scheme", (char *) theme_thumbnail_data->gtk_color_scheme->data,
     NULL);
+
   theme = meta_theme_load ((char *) theme_thumbnail_data->wm_theme_name->data, NULL);
+  if (theme == NULL)
+    return NULL;
 
   /* Represent the icon theme */
   icon = create_folder_icon ((char *) theme_thumbnail_data->icon_theme_name->data);
@@ -473,6 +445,8 @@ create_metacity_theme_pixbuf (ThemeThumbnailData *theme_thumbnail_data)
   GdkRegion *region;
 
   theme = meta_theme_load ((char *) theme_thumbnail_data->wm_theme_name->data, NULL);
+  if (theme == NULL)
+    return NULL;
 
   flags = META_FRAME_ALLOWS_DELETE |
           META_FRAME_ALLOWS_MENU |
@@ -678,9 +652,6 @@ message_from_capplet (GIOChannel   *source,
   gchar buffer[1024];
   GIOStatus status;
   gsize bytes_read;
-  GdkPixbuf *pixbuf;
-  gint i, rowstride;
-  guchar *pixels;
   ThemeThumbnailData *theme_thumbnail_data;
 
   theme_thumbnail_data = (ThemeThumbnailData *) data;
@@ -697,9 +668,11 @@ message_from_capplet (GIOChannel   *source,
 
       if (theme_thumbnail_data->status == WRITING_PIXBUF_DATA)
       {
-        char *type;
+        GdkPixbuf *pixbuf = NULL;
+        gint i, rowstride;
+        guchar *pixels;
         gint width, height;
-        type = (char *) theme_thumbnail_data->type->data;
+        const gchar *type = (const gchar *) theme_thumbnail_data->type->data;
 
         if (!strcmp (type, THUMBNAIL_TYPE_META))
           pixbuf = create_meta_theme_pixbuf (theme_thumbnail_data);
@@ -712,10 +685,15 @@ message_from_capplet (GIOChannel   *source,
         else
           g_assert_not_reached ();
 
-        width = gdk_pixbuf_get_width (pixbuf);
-        height = gdk_pixbuf_get_height (pixbuf);
-        rowstride = gdk_pixbuf_get_rowstride (pixbuf);
-        pixels = gdk_pixbuf_get_pixels (pixbuf);
+        if (pixbuf == NULL) {
+          width = height = rowstride = 0;
+          pixels = NULL;
+        } else {
+          width = gdk_pixbuf_get_width (pixbuf);
+          height = gdk_pixbuf_get_height (pixbuf);
+          rowstride = gdk_pixbuf_get_rowstride (pixbuf);
+          pixels = gdk_pixbuf_get_pixels (pixbuf);
+        }
 
         /* Write the pixbuf's size */
         write (pipe_from_factory_fd[1], &width, sizeof (width));
@@ -723,16 +701,18 @@ message_from_capplet (GIOChannel   *source,
 
         for (i = 0; i < height; i++)
         {
-          write (pipe_from_factory_fd[1], pixels + (rowstride)*i, width * gdk_pixbuf_get_n_channels (pixbuf));
+          write (pipe_from_factory_fd[1], pixels + rowstride * i, width * gdk_pixbuf_get_n_channels (pixbuf));
         }
-        g_object_unref (pixbuf);
-        theme_thumbnail_data->status = READY_FOR_THEME;
+
+        if (pixbuf)
+          g_object_unref (pixbuf);
         g_byte_array_set_size (theme_thumbnail_data->type, 0);
         g_byte_array_set_size (theme_thumbnail_data->control_theme_name, 0);
         g_byte_array_set_size (theme_thumbnail_data->gtk_color_scheme, 0);
         g_byte_array_set_size (theme_thumbnail_data->wm_theme_name, 0);
         g_byte_array_set_size (theme_thumbnail_data->icon_theme_name, 0);
         g_byte_array_set_size (theme_thumbnail_data->application_font, 0);
+        theme_thumbnail_data->status = READY_FOR_THEME;
       }
       return TRUE;
 
@@ -798,9 +778,7 @@ message_from_child (GIOChannel   *source,
     return TRUE;
 
   if (condition == G_IO_HUP)
-  {
     return FALSE;
-  }
 
   status = g_io_channel_read_chars (source,
                                     buffer,
@@ -812,39 +790,46 @@ message_from_child (GIOChannel   *source,
     case G_IO_STATUS_NORMAL:
       g_byte_array_append (async_data.data, (guchar *) buffer, bytes_read);
 
-      if (async_data.thumbnail_width == 0 && async_data.data->len >= 2 * sizeof (gint))
+      if (async_data.thumbnail_width == -1 && async_data.data->len >= 2 * sizeof (gint))
       {
         async_data.thumbnail_width = *((gint *) async_data.data->data);
         async_data.thumbnail_height = *(((gint *) async_data.data->data) + 1);
         g_byte_array_remove_range (async_data.data, 0, 2 * sizeof (gint));
       }
-      else if (async_data.thumbnail_width > 0 && async_data.data->len == async_data.thumbnail_width * async_data.thumbnail_height * 4)
+
+      if (async_data.thumbnail_width >= 0 && async_data.data->len == async_data.thumbnail_width * async_data.thumbnail_height * 4)
       {
-        GdkPixbuf *pixbuf;
-        gchar *pixels;
-        gint i, rowstride;
+        GdkPixbuf *pixbuf = NULL;
 
-        pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, async_data.thumbnail_width, async_data.thumbnail_height);
-        pixels = (gchar *) gdk_pixbuf_get_pixels (pixbuf);
-        rowstride = gdk_pixbuf_get_rowstride (pixbuf);
+        if (async_data.thumbnail_width > 0) {
+          gchar *pixels;
+          gint i, rowstride;
 
-        for (i = 0; i < async_data.thumbnail_height; i++)
-          memcpy (pixels + rowstride * i, async_data.data->data + 4 * async_data.thumbnail_width * i, async_data.thumbnail_width * 4);
+          pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, async_data.thumbnail_width, async_data.thumbnail_height);
+          pixels = (gchar *) gdk_pixbuf_get_pixels (pixbuf);
+          rowstride = gdk_pixbuf_get_rowstride (pixbuf);
 
-        /* callback function needs to unref the pixbuf */
+          for (i = 0; i < async_data.thumbnail_height; ++i)
+            memcpy (pixels + rowstride * i, async_data.data->data + 4 * async_data.thumbnail_width * i, async_data.thumbnail_width * 4);
+        }
+
+        /* callback function needs to ref the pixbuf if it wants to keep it */
         (* async_data.func) (pixbuf, async_data.theme_name, async_data.user_data);
 
         if (async_data.destroy)
           (* async_data.destroy) (async_data.user_data);
 
+        if (pixbuf)
+          g_object_unref (pixbuf);
+
         /* Clean up async_data */
         g_free (async_data.theme_name);
         g_source_remove (async_data.watch_id);
         g_io_channel_unref (async_data.channel);
 
         /* reset async_data */
-        async_data.thumbnail_width = 0;
-        async_data.thumbnail_height = 0;
+        async_data.thumbnail_width = -1;
+        async_data.thumbnail_height = -1;
         async_data.theme_name = NULL;
         async_data.channel = NULL;
         async_data.func = NULL;
@@ -920,10 +905,15 @@ read_pixbuf (void)
   do
   {
     bytes_read = read (pipe_from_factory_fd[0], ((guint8*) size) + j, 2 * sizeof (gint));
+    if (bytes_read == 0)
+      goto eof;
     j += bytes_read;
   }
   while (j < 2 * sizeof (gint));
 
+  if (size[0] <= 0 || size[1] <= 0)
+    return NULL;
+
   pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, size[0], size[1]);
   rowstride = gdk_pixbuf_get_rowstride (pixbuf);
   pixels = gdk_pixbuf_get_pixels (pixbuf);
@@ -934,25 +924,28 @@ read_pixbuf (void)
 
     do
     {
-      bytes_read = read (pipe_from_factory_fd[0], pixels + (rowstride)*i + j, size[0] * gdk_pixbuf_get_n_channels (pixbuf) - j);
+      bytes_read = read (pipe_from_factory_fd[0], pixels + rowstride * i + j, size[0] * gdk_pixbuf_get_n_channels (pixbuf) - j);
 
       if (bytes_read > 0)
         j += bytes_read;
       else if (bytes_read == 0)
       {
-        g_warning ("Received EOF while reading thumbnail");
         g_object_unref (pixbuf);
-        close (pipe_to_factory_fd[1]);
-        pipe_to_factory_fd[1] = 0;
-        close (pipe_from_factory_fd[0]);
-        pipe_from_factory_fd[0] = 0;
-        return NULL;
+        goto eof;
       }
     }
     while (j < size[0] * gdk_pixbuf_get_n_channels (pixbuf));
   }
 
   return pixbuf;
+
+eof:
+  g_warning ("Received EOF while reading thumbnail");
+  close (pipe_to_factory_fd[1]);
+  pipe_to_factory_fd[1] = 0;
+  close (pipe_from_factory_fd[0]);
+  pipe_from_factory_fd[0] = 0;
+  return NULL;
 }
 
 static GdkPixbuf *
@@ -1072,8 +1065,8 @@ generate_theme_thumbnail_async (gpointer            theme_info,
   }
 
   async_data.set = TRUE;
-  async_data.thumbnail_width = 0;
-  async_data.thumbnail_height = 0;
+  async_data.thumbnail_width = -1;
+  async_data.thumbnail_height = -1;
   async_data.theme_name = g_strdup (theme_name);
   async_data.func = func;
   async_data.user_data = user_data;
@@ -1163,9 +1156,19 @@ generate_icon_theme_thumbnail_async (GnomeThemeIconInfo *theme_info,
 void
 theme_thumbnail_factory_init (int argc, char *argv[])
 {
+#ifndef __APPLE__
+  gint child_pid;
+#endif
+
   pipe (pipe_to_factory_fd);
   pipe (pipe_from_factory_fd);
 
+/* Apple's CoreFoundation classes must not be used from forked
+ * processes. Since freetype (and thus GTK) uses them, we simply
+ * disable the thumbnailer on MacOS for now. That means no thumbs
+ * until the thumbnailing process is rewritten, but at least we won't
+ * make apps crash. */
+#ifndef __APPLE__
   child_pid = fork ();
   if (child_pid == 0)
   {
@@ -1204,10 +1207,9 @@ theme_thumbnail_factory_init (int argc, char *argv[])
   /* Parent */
   close (pipe_to_factory_fd[0]);
   close (pipe_from_factory_fd[1]);
+#endif /* __APPLE__ */
+
   async_data.set = FALSE;
-  async_data.thumbnail_width = 0;
-  async_data.thumbnail_height = 0;
   async_data.theme_name = NULL;
   async_data.data = g_byte_array_new ();
 }
-
