@@ -29,44 +29,44 @@
 #include "libgnomekbd/gkbd-keyboard-config.h"
 
 G_BEGIN_DECLS
-#define CWID(s) glade_xml_get_widget (chooser_dialog, s)
+#define CWID(s) GTK_WIDGET (gtk_builder_get_object (chooser_dialog, s))
 extern XklEngine *engine;
 extern XklConfigRegistry *config_registry;
 extern GConfClient *xkb_gconf_client;
 extern GkbdKeyboardConfig initial_config;
 
-extern void setup_xkb_tabs (GladeXML * dialog, GConfChangeSet * changeset);
+extern void setup_xkb_tabs (GtkBuilder * dialog, GConfChangeSet * changeset);
 
-extern void xkb_layouts_fill_selected_tree (GladeXML * dialog);
+extern void xkb_layouts_fill_selected_tree (GtkBuilder * dialog);
 
-extern void xkb_layouts_register_buttons_handlers (GladeXML * dialog);
+extern void xkb_layouts_register_buttons_handlers (GtkBuilder * dialog);
 
-extern void xkb_layouts_register_gconf_listener (GladeXML * dialog);
+extern void xkb_layouts_register_gconf_listener (GtkBuilder * dialog);
 
-extern void xkb_options_register_gconf_listener (GladeXML * dialog);
+extern void xkb_options_register_gconf_listener (GtkBuilder * dialog);
 
-extern void xkb_layouts_prepare_selected_tree (GladeXML * dialog,
+extern void xkb_layouts_prepare_selected_tree (GtkBuilder * dialog,
 					       GConfChangeSet * changeset);
 
-extern void xkb_options_load_options (GladeXML * dialog);
+extern void xkb_options_load_options (GtkBuilder * dialog);
 
-extern void xkb_options_popup_dialog(GladeXML * dialog);
+extern void xkb_options_popup_dialog (GtkBuilder * dialog);
 
 extern void clear_xkb_elements_list (GSList * list);
 
 extern char *xci_desc_to_utf8 (XklConfigItem * ci);
 
-extern gchar *xkb_layout_description_utf8 (const gchar *visible);
+extern gchar *xkb_layout_description_utf8 (const gchar * visible);
 
-extern void enable_disable_restoring (GladeXML * dialog);
+extern void enable_disable_restoring (GtkBuilder * dialog);
 
-extern void preview_toggled (GladeXML * dialog, GtkWidget * button);
+extern void preview_toggled (GtkBuilder * dialog, GtkWidget * button);
 
-extern void choose_model (GladeXML * dialog);
+extern void choose_model (GtkBuilder * dialog);
 
-extern void xkb_layout_choose (GladeXML * dialog);
+extern void xkb_layout_choose (GtkBuilder * dialog);
 
-extern void xkb_layouts_enable_disable_default (GladeXML * dialog,
+extern void xkb_layouts_enable_disable_default (GtkBuilder * dialog,
 						gboolean enable);
 
 extern GSList *xkb_layouts_get_selected_list (void);
@@ -83,15 +83,15 @@ extern GSList *xkb_options_get_selected_list (void);
                                GKBD_KEYBOARD_CONFIG_KEY_OPTIONS, \
                                GCONF_VALUE_STRING, (list), NULL)
 
-extern GtkWidget *xkb_layout_preview_create_widget (GladeXML *
+extern GtkWidget *xkb_layout_preview_create_widget (GtkBuilder *
 						    chooser_dialog);
 
-extern void xkb_layout_preview_update (GladeXML * chooser_dialog);
+extern void xkb_layout_preview_update (GtkBuilder * chooser_dialog);
 
-extern void xkb_layout_preview_set_drawing_layout (GtkWidget   *kbdraw,
-                                                   const gchar *id);
+extern void xkb_layout_preview_set_drawing_layout (GtkWidget * kbdraw,
+						   const gchar * id);
 
-extern gchar *xkb_layout_chooser_get_selected_id (GladeXML *
+extern gchar *xkb_layout_chooser_get_selected_id (GtkBuilder *
 						  chooser_dialog);
 
 G_END_DECLS
