@@ -19,12 +19,12 @@
  */
 
 #include "directory-tile.h"
+#include "config.h"
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <string.h>
-#include <libgnomeui/gnome-icon-lookup.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
-#include <libgnomevfs/gnome-vfs.h>
+#include <gio/gio.h>
+#include <gdk/gdk.h>
 #include <unistd.h>
 
 #include "slab-gnome-util.h"
@@ -67,7 +67,7 @@ typedef struct
 	gchar *icon_name;
 	
 	GtkBin *header_bin;
-	GnomeVFSMimeApplication *default_app;
+	GAppInfo *default_app;
 	
 	gboolean image_is_broken;
 	
@@ -121,7 +121,7 @@ directory_tile_new (const gchar *in_uri, const gchar *title, const gchar *icon_n
 
 	if (! title) {
 		markup = g_path_get_basename (uri);
-		basename = gnome_vfs_unescape_string (markup, NULL);
+		basename = g_uri_unescape_string (markup, NULL);
 		g_free (markup);
 	}
 	else
@@ -145,9 +145,9 @@ directory_tile_new (const gchar *in_uri, const gchar *title, const gchar *icon_n
 		"tile-uri",          uri,
 		"nameplate-image",   image,
 		"nameplate-header",  header,
-		"nameplate-tooltip", tooltip_text,
 		"context-menu",      context_menu,
 		NULL);
+	gtk_widget_set_tooltip_text (GTK_WIDGET (this), tooltip_text);
 
 	g_free (uri);
 	if (tooltip_text)
@@ -262,7 +262,7 @@ directory_tile_private_setup (DirectoryTile *tile)
 	GConfClient *client;
 
 	if (priv->mime_type)
-		priv->default_app = gnome_vfs_mime_get_default_application (priv->mime_type);
+		priv->default_app = g_app_info_get_default_for_type (priv->mime_type, TRUE);
 	else
 		priv->default_app = NULL;
 
@@ -304,7 +304,8 @@ directory_tile_finalize (GObject *g_object)
 	g_free (priv->icon_name);
 	g_free (priv->mime_type);
 
-	gnome_vfs_mime_application_free (priv->default_app);
+	if (priv->default_app)
+		g_object_unref (priv->default_app);
     
 	client = gconf_client_get_default ();
 
@@ -368,41 +369,48 @@ rename_entry_activate_cb (GtkEntry *entry, gpointer user_data)
 	DirectoryTile *tile = DIRECTORY_TILE (user_data);
 	DirectoryTilePrivate *priv = DIRECTORY_TILE_GET_PRIVATE (tile);
 
-	GnomeVFSURI *src_uri;
-	GnomeVFSURI *dst_uri;
+	GFile *src_file;
+	GFile *dst_file;
 
 	gchar *dirname;
-	gchar *dst_path;
-	gchar *dst_uri_str;
+	gchar *dst_uri;
+	gchar *src_path;
 
 	GtkWidget *child;
 	GtkWidget *header;
 
-	GnomeVFSResult retval;
-
+	gboolean res;
+	GError *error = NULL;
 
 	if (strlen (gtk_entry_get_text (entry)) < 1)
 		return;
 
-	src_uri = gnome_vfs_uri_new (TILE (tile)->uri);
+	src_file = g_file_new_for_uri (TILE (tile)->uri);
 
-	dirname = gnome_vfs_uri_extract_dirname (src_uri);
+	src_path = g_filename_from_uri (TILE (tile)->uri, NULL, NULL);
+	dirname = g_path_get_dirname (src_path);
+	dst_uri = g_build_filename (dirname, gtk_entry_get_text (entry), NULL);
+	dst_file = g_file_new_for_uri (dst_uri);
 
-	dst_path = g_build_filename (dirname, gtk_entry_get_text (entry), NULL);
+	g_free (dirname);
+	g_free (src_path);
 
-	dst_uri = gnome_vfs_uri_new (dst_path);
+	res = g_file_move (src_file, dst_file,
+			   G_FILE_COPY_NONE, NULL, NULL, NULL, &error);
 
-	retval = gnome_vfs_xfer_uri (src_uri, dst_uri, GNOME_VFS_XFER_REMOVESOURCE,
-		GNOME_VFS_XFER_ERROR_MODE_ABORT, GNOME_VFS_XFER_OVERWRITE_MODE_SKIP, NULL, NULL);
-
-	dst_uri_str = gnome_vfs_uri_to_string (dst_uri, GNOME_VFS_URI_HIDE_NONE);
-
-	if (retval == GNOME_VFS_OK) {
+	if (res) {
 		g_free (priv->basename);
 		priv->basename = g_strdup (gtk_entry_get_text (entry));
 	}
-	else
-		g_warning ("unable to move [%s] to [%s]\n", TILE (tile)->uri, dst_uri_str);
+	else {
+		g_warning ("unable to move [%s] to [%s]: %s\n", TILE (tile)->uri, dst_uri,
+			   error->message);
+		g_error_free (error);
+	}
+
+	g_free (dst_uri);
+	g_object_unref (src_file);
+	g_object_unref (dst_file);
 
 	header = gtk_label_new (priv->basename);
 	gtk_misc_set_alignment (GTK_MISC (header), 0.0, 0.5);
@@ -415,13 +423,6 @@ rename_entry_activate_cb (GtkEntry *entry, gpointer user_data)
 	gtk_container_add (GTK_CONTAINER (priv->header_bin), header);
 
 	gtk_widget_show (header);
-
-	gnome_vfs_uri_unref (src_uri);
-	gnome_vfs_uri_unref (dst_uri);
-
-	g_free (dirname);
-	g_free (dst_path);
-	g_free (dst_uri_str);
 }
 
 static gboolean
@@ -501,53 +502,20 @@ rename_trigger (Tile *tile, TileEvent *event, TileAction *action)
 static void
 move_to_trash_trigger (Tile *tile, TileEvent *event, TileAction *action)
 {
-	GnomeVFSURI *src_uri;
-	GnomeVFSURI *trash_uri;
+	GFile *src_file;
+	gboolean res;
+	GError *error = NULL;
 
-	gchar *file_name;
-	gchar *trash_uri_str;
+	src_file = g_file_new_for_uri (TILE (tile)->uri);
 
-	GnomeVFSResult retval;
-
-
-	src_uri = gnome_vfs_uri_new (TILE (tile)->uri);
-
-	gnome_vfs_find_directory (src_uri, GNOME_VFS_DIRECTORY_KIND_TRASH, &trash_uri,
-		FALSE, FALSE, 0777);
-
-	if (!trash_uri) {
-		g_warning ("unable to find trash location\n");
-
-		return;
+	res = g_file_trash (src_file, NULL, &error);
+	if (!res) {
+		g_warning ("unable to move [%s] to the trash: %s\n", TILE (tile)->uri,
+			   error->message);
+		g_error_free (error);
 	}
 
-	file_name = gnome_vfs_uri_extract_short_name (src_uri);
-
-	if (!file_name) {
-		g_warning ("unable to extract short name from [%s]\n",
-			gnome_vfs_uri_to_string (src_uri, GNOME_VFS_URI_HIDE_NONE));
-
-		return;
-	}
-
-	trash_uri = gnome_vfs_uri_append_file_name (trash_uri, file_name);
-
-	retval = gnome_vfs_xfer_uri (src_uri, trash_uri, GNOME_VFS_XFER_REMOVESOURCE,
-		GNOME_VFS_XFER_ERROR_MODE_ABORT, GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE, NULL, NULL);
-
-	if (retval != GNOME_VFS_OK) {
-		trash_uri_str = gnome_vfs_uri_to_string (trash_uri, GNOME_VFS_URI_HIDE_NONE);
-
-		g_warning ("unable to move [%s] to the trash [%s]\n", TILE (tile)->uri,
-			trash_uri_str);
-
-		g_free (trash_uri_str);
-	}
-
-	gnome_vfs_uri_unref (src_uri);
-	gnome_vfs_uri_unref (trash_uri);
-
-	g_free (file_name);
+	g_object_unref (src_file);
 }
 
 static void
@@ -556,11 +524,9 @@ delete_trigger (Tile *tile, TileEvent *event, TileAction *action)
 	GtkDialog *confirm_dialog;
 	gint       result;
 
-	GnomeVFSURI *src_uri;
-	GList *list = NULL;
-
-	GnomeVFSResult retval;
-
+	GFile *src_file;
+	gboolean res;
+	GError *error = NULL;
 
 	if (GPOINTER_TO_INT (libslab_get_gconf_value (GCONF_CONFIRM_DELETE_KEY))) {
 		confirm_dialog = GTK_DIALOG(gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_WARNING, 
@@ -579,18 +545,17 @@ delete_trigger (Tile *tile, TileEvent *event, TileAction *action)
 			return;
 	}
 
-	src_uri = gnome_vfs_uri_new (TILE (tile)->uri);
+	src_file = g_file_new_for_uri (TILE (tile)->uri);
 
-	list = g_list_append (list, src_uri);
+	res = g_file_delete (src_file, NULL, &error);
 
-	retval = gnome_vfs_xfer_delete_list (list, GNOME_VFS_XFER_ERROR_MODE_ABORT,
-		GNOME_VFS_XFER_REMOVESOURCE, NULL, NULL);
+	if (!res) {
+		g_warning ("unable to delete [%s]: %s\n", TILE (tile)->uri,
+			   error->message);
+		g_error_free (error);
+	}
 
-	if (retval != GNOME_VFS_OK)
-		g_warning ("unable to delete [%s]\n", TILE (tile)->uri);
-
-	gnome_vfs_uri_unref (src_uri);
-	g_list_free (list);
+	g_object_unref (src_file);
 }
 
 static void
@@ -667,20 +632,33 @@ open_with_default_trigger (Tile *tile, TileEvent *event, TileAction *action)
 {
 	DirectoryTilePrivate *priv = DIRECTORY_TILE_GET_PRIVATE (tile);
 	GList *uris = NULL;
-	GnomeVFSResult retval;
+	gboolean res;
+	GdkAppLaunchContext *launch_context;
+	GError *error = NULL;
 
 	if (priv->default_app)
 	{
 		uris = g_list_append (uris, TILE (tile)->uri);
+		
+		launch_context = gdk_app_launch_context_new ();
+		gdk_app_launch_context_set_screen (launch_context,
+						   gtk_widget_get_screen (GTK_WIDGET (tile)));
+		gdk_app_launch_context_set_timestamp (launch_context,
+						      event->time);
 
-		retval = gnome_vfs_mime_application_launch (priv->default_app, uris);
+		res = g_app_info_launch_uris (priv->default_app, uris,
+					      G_APP_LAUNCH_CONTEXT (launch_context),
+					      &error);
 
-		if (retval != GNOME_VFS_OK)
+		if (!res) {
 			g_warning
-				("error: could not launch application with [%s].  GnomeVFSResult = %d\n",
-				TILE (tile)->uri, retval);
+				("error: could not launch application with [%s]: %s\n",
+				 TILE (tile)->uri, error->message);
+			g_error_free (error);
+		}
 
 		g_list_free (uris);
+		g_object_unref (launch_context);
 	} else {
 		gchar *cmd;
 		cmd = string_replace_once (
